pub struct Days {
pub sunday: bool,
pub monday: bool,
pub tuesday: bool,
pub wednesday: bool,
pub thursday: bool,
pub friday: bool,
pub saturday: bool,
}Expand description
Whether an anime airs multiple times a week and which days specifically. Used only if it airs multiple times a week.
Fields
sunday: boolmonday: booltuesday: boolwednesday: boolthursday: boolfriday: boolsaturday: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Days
impl<'de> Deserialize<'de> for Days
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more