TimetableAnime

Struct TimetableAnime 

pub struct TimetableAnime {
Show 20 fields pub title: String, pub route: String, pub romaji: Option<String>, pub english: Option<String>, pub native: Option<String>, pub delayed_text: Option<String>, pub delayed_from: Option<DateTime<FixedOffset>>, pub delayed_until: Option<DateTime<FixedOffset>>, pub status: AirStatus, pub episode_date: DateTime<FixedOffset>, pub episode_number: u64, pub subtracted_episode_number: Option<u64>, pub episodes: Option<u64>, pub length_min: Option<u64>, pub donghua: bool, pub air_type: AirType, pub media_types: Vec<Category>, pub image_version_route: String, pub streams: Streams, pub airing_status: AiringStatus,
}

Fields

title: String

The display title. Separate from other names and used as a high-priority name in some cases.

route: String

The unique URL slug.

romaji: Option<String>

The Romaji name.

english: Option<String>

The English name.

native: Option<String>

The Native name.

delayed_text: Option<String>

The timetable delayed display text.

delayed_from: Option<DateTime<FixedOffset>>

The date from which it has been delayed.

delayed_until: Option<DateTime<FixedOffset>>

The date until it has been delayed to.

status: AirStatus

The airing status.

episode_date: DateTime<FixedOffset>

The episode’s date and time.

episode_number: u64

The episode’s number.

subtracted_episode_number: Option<u64>

The lowest episode number. Used only if multiple episodes air. The full format is SubtractedEpisodeNumber - EpisodeNumber.

episodes: Option<u64>

The total episodes of an anime. 0 indicates unknown.

length_min: Option<u64>

The length of an episode in minutes.

donghua: bool

Whether a timetable anime is a donghua/chinese.

air_type: AirType

The air type. Raw and Dub will only display timetable anime that match it. Sub will use Raw if Sub is not available.

media_types: Vec<Category>

The timetable anime’s media types in an array of the category object.

image_version_route: String

The timetable anime’s poster/image URL slug.

streams: Streamsairing_status: AiringStatus

The episode’s immediate timetable status.